#!/bin/sh

PAUSE="0 100 200 300 400 500 600 700 800 900"
TRIALS="1 2 3 4 5 6 7 8 9 10"

echo WiFi Experiment Example

pCheck=`which sqlite3`
if [ -z "$pCheck" ]
then
  echo "ERROR: This script requires sqlite3 (wifi-example-sim does not)."
  exit 255
fi

pCheck=`which gnuplot`
if [ -z "$pCheck" ]
then
  echo "ERROR: This script requires gnuplot (wifi-example-sim does not)."
  exit 255
fi

pCheck=`which sed`
if [ -z "$pCheck" ]
then
  echo "ERROR: This script requires sed (wifi-example-sim does not)."
  exit 255
fi

export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:bin/

# Remove existing database
if [ -e data.db ]
then
  echo "Kill data.db? (y/n)"
  read ANS
  if [ "$ANS" = "yes" -o "$ANS" = "y" ]
  then
    echo Deleting database
    rm data.db
  fi
fi

# Compile the simulation scenario with the different parameters, and run the number of trials
for pause in $PAUSE
do
  for trial in $TRIALS
  do
    echo
    echo Pause time $pause, Trial $trial
    export NS_GLOBAL_VALUE="RngRun=$trial"
    ./waf --run "main-scenario --format=db --batman=1 --pause=$pause --start=30 --stop=930 --sources=20"
  done
done

# Create SQL command to get packet delivery ratio
PDR_CMD="SELECT rx.run, avg(cast(rx.value as real)/cast(tx.value as real)) 
		FROM Singletons rx, Singletons tx 
		WHERE rx.variable = 'onoffRx' AND tx.variable='onoffTx'
		GROUP BY rx.run
		ORDER BY rx.run ASC;"

# Get OnOff packet delay results
DELAY_CMD="SELECT onoff.run, (avg(onoff.value)/1000000000) 
	FROM Singletons onoff
	WHERE onoff.variable = 'onoffDelay-average'
	GROUP BY onoff.run;"

# Get MAC packet delay results 
MAC_CMD="SELECT mac.run, (avg(mac.value)/1000000000) 
	FROM Singletons mac
	WHERE mac.variable = 'macDelay-average'
	GROUP BY mac.run;"

# Amount transmitted and received BATMAN packets AVG!
BATMAN_CMD="SELECT batmant.run, batmant.value, batmanr.value 
	FROM Singletons batmant, Singletons batmanr
	WHERE batmant.variable = 'batmanTx' AND batmanr.variable = 'batmanRx'
	GROUP BY batmant.run;"

# Amount transmitted and received DSDV packets AVG!
DSDV_CMD="SELECT dsdvt.run, dsdvt.value, dsdvr.value 
	FROM Singletons dsdvt, Singletons dsdvr
	WHERE dsdvt.variable = 'dsdvTx' AND dsdvr.variable = 'dsdvRx'
	GROUP BY dsdvt.run;"

# Get everything!
ALL_CMD="SELECT * FROM Singletons;"

# Query the SQLite Database
sqlite3 -noheader data.db "$PDR_CMD" > test.data

# Parse the data
sed -i "s/run-//" test.data
sed -i "s/|/   /" test.data

# Run gnuplot script and create graph
#gnuplot main-delay.gnuplot
#gnuplot main-overhead.gnuplot
gnuplot main-pdr.gnuplot

echo "Done;"
